@@ -12,8 +12,8 @@
 #' In general, TAF scripts do not access the internet using
 #' \code{download.github} or similar functions. Instead, data and software are
 #' declared in \verb{DATA.bib} and \verb{SOFTWARE.bib} and then downloaded using
-#' \code{\link{taf.bootstrap}}. The exception is when a bootstrap data script is
-#' used to fetch data files from a web service (see
+#' \code{\link{taf.bootstrap}}. The exception is when a bootstrap script is used
+#' to fetch files from a web service (see
 #' \href{https://github.com/ices-taf/doc/wiki/Bib-entries}{TAF Wiki}).
 #'
 #' @seealso
@@ -63,18 +63,12 @@ download.github <- function(repo, dir=".", quiet=FALSE)
   if(subdir=="" && file.exists(targz))  # no subdir, targz exists
   {
     if(!quiet)
-    {
-      message("Skipping download of '", targz, "'.")
-      message("  Version '", sha, "' is already in ", dir)
-    }
+      message("  Skipping download of '", targz, "' (already in place).")
   }
   else if(subdir!="" && file.exists(subtargz))  # subdir, subtargz exists
   {
     if(!quiet)
-    {
-      message("Skipping download of '", subtargz, "'.")
-      message("  Version '", sha, "' is already in ", dir)
-    }
+      message("  Skipping download of '", subtargz, "' (already in place).")
   }
   else
   {
